/********************************************************************************
** Form generated from reading UI file 'fontconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTCONFIGDIALOG_H
#define UI_FONTCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_FontConfigDialog
{
public:
    QGridLayout *gridLayout;
    QCheckBox *disableBoldAutohintCheckBox;
    QLabel *label_3;
    QCheckBox *autohinterCheckBox;
    QCheckBox *hintingCheckBox;
    QDialogButtonBox *buttonBox;
    QLabel *label_4;
    QComboBox *lcdFilterComboBox;
    QComboBox *rgbaComboBox;
    QComboBox *hintingStyleComboBox;
    QLabel *label_2;
    QCheckBox *antialisingCheckBox;
    QLabel *label;
    QSpinBox *dpiSpinBox;

    void setupUi(QDialog *FontConfigDialog)
    {
        if (FontConfigDialog->objectName().isEmpty())
            FontConfigDialog->setObjectName(QStringLiteral("FontConfigDialog"));
        FontConfigDialog->resize(349, 286);
        gridLayout = new QGridLayout(FontConfigDialog);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(6, -1, 6, 6);
        disableBoldAutohintCheckBox = new QCheckBox(FontConfigDialog);
        disableBoldAutohintCheckBox->setObjectName(QStringLiteral("disableBoldAutohintCheckBox"));

        gridLayout->addWidget(disableBoldAutohintCheckBox, 5, 0, 1, 2);

        label_3 = new QLabel(FontConfigDialog);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 6, 0, 1, 1);

        autohinterCheckBox = new QCheckBox(FontConfigDialog);
        autohinterCheckBox->setObjectName(QStringLiteral("autohinterCheckBox"));

        gridLayout->addWidget(autohinterCheckBox, 4, 0, 1, 2);

        hintingCheckBox = new QCheckBox(FontConfigDialog);
        hintingCheckBox->setObjectName(QStringLiteral("hintingCheckBox"));

        gridLayout->addWidget(hintingCheckBox, 1, 0, 1, 2);

        buttonBox = new QDialogButtonBox(FontConfigDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 8, 0, 1, 2);

        label_4 = new QLabel(FontConfigDialog);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout->addWidget(label_4, 7, 0, 1, 1);

        lcdFilterComboBox = new QComboBox(FontConfigDialog);
        lcdFilterComboBox->setObjectName(QStringLiteral("lcdFilterComboBox"));

        gridLayout->addWidget(lcdFilterComboBox, 6, 1, 1, 1);

        rgbaComboBox = new QComboBox(FontConfigDialog);
        rgbaComboBox->setObjectName(QStringLiteral("rgbaComboBox"));

        gridLayout->addWidget(rgbaComboBox, 3, 1, 1, 1);

        hintingStyleComboBox = new QComboBox(FontConfigDialog);
        hintingStyleComboBox->setObjectName(QStringLiteral("hintingStyleComboBox"));

        gridLayout->addWidget(hintingStyleComboBox, 2, 1, 1, 1);

        label_2 = new QLabel(FontConfigDialog);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        antialisingCheckBox = new QCheckBox(FontConfigDialog);
        antialisingCheckBox->setObjectName(QStringLiteral("antialisingCheckBox"));

        gridLayout->addWidget(antialisingCheckBox, 0, 0, 1, 2);

        label = new QLabel(FontConfigDialog);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 2, 0, 1, 1);

        dpiSpinBox = new QSpinBox(FontConfigDialog);
        dpiSpinBox->setObjectName(QStringLiteral("dpiSpinBox"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(dpiSpinBox->sizePolicy().hasHeightForWidth());
        dpiSpinBox->setSizePolicy(sizePolicy);
        dpiSpinBox->setMinimum(80);
        dpiSpinBox->setMaximum(180);
        dpiSpinBox->setValue(102);

        gridLayout->addWidget(dpiSpinBox, 7, 1, 1, 1);


        retranslateUi(FontConfigDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), FontConfigDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), FontConfigDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(FontConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *FontConfigDialog)
    {
        FontConfigDialog->setWindowTitle(QApplication::translate("FontConfigDialog", "Font Configuration", 0));
        disableBoldAutohintCheckBox->setText(QApplication::translate("FontConfigDialog", "Disable automatic hinting for bold fonts", 0));
        label_3->setText(QApplication::translate("FontConfigDialog", "LCD filter:", 0));
        autohinterCheckBox->setText(QApplication::translate("FontConfigDialog", "Automatic hinting", 0));
        hintingCheckBox->setText(QApplication::translate("FontConfigDialog", "Hinting", 0));
        label_4->setText(QApplication::translate("FontConfigDialog", "Font resolution:", 0));
        label_2->setText(QApplication::translate("FontConfigDialog", "Subpixel geometry:", 0));
        antialisingCheckBox->setText(QApplication::translate("FontConfigDialog", "Antialiasing", 0));
        label->setText(QApplication::translate("FontConfigDialog", "Hinting style:", 0));
        dpiSpinBox->setSuffix(QApplication::translate("FontConfigDialog", " dpi", 0));
    } // retranslateUi

};

namespace Ui {
    class FontConfigDialog: public Ui_FontConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FONTCONFIGDIALOG_H
