/********************************************************************************
** Form generated from reading UI file 'appearancepage.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPEARANCEPAGE_H
#define UI_APPEARANCEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMdiArea>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AppearancePage
{
public:
    QGridLayout *gridLayout_4;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QComboBox *paletteComboBox;
    QSpacerItem *horizontalSpacer_2;
    QMdiArea *mdiArea;
    QComboBox *styleComboBox;
    QSpacerItem *horizontalSpacer;
    QGroupBox *paletteGroupBox;
    QVBoxLayout *_2;
    QHBoxLayout *horizontalLayout;
    QRadioButton *defaultPaletteButton;
    QRadioButton *customPaletteButton;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *colorScheeLabel;
    QComboBox *colorSchemeComboBox;
    QToolButton *colorSchemeButton;
    QSpacerItem *horizontalSpacer_4;

    void setupUi(QWidget *AppearancePage)
    {
        if (AppearancePage->objectName().isEmpty())
            AppearancePage->setObjectName(QStringLiteral("AppearancePage"));
        AppearancePage->resize(596, 470);
        AppearancePage->setWindowTitle(QStringLiteral("Form"));
        gridLayout_4 = new QGridLayout(AppearancePage);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        label = new QLabel(AppearancePage);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_4->addWidget(label, 0, 0, 1, 1);

        groupBox = new QGroupBox(AppearancePage);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        paletteComboBox = new QComboBox(groupBox);
        paletteComboBox->setObjectName(QStringLiteral("paletteComboBox"));

        gridLayout->addWidget(paletteComboBox, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(82, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        mdiArea = new QMdiArea(groupBox);
        mdiArea->setObjectName(QStringLiteral("mdiArea"));
        mdiArea->setTabsMovable(false);

        gridLayout->addWidget(mdiArea, 1, 0, 1, 2);


        gridLayout_4->addWidget(groupBox, 3, 0, 1, 3);

        styleComboBox = new QComboBox(AppearancePage);
        styleComboBox->setObjectName(QStringLiteral("styleComboBox"));

        gridLayout_4->addWidget(styleComboBox, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 2, 1, 1);

        paletteGroupBox = new QGroupBox(AppearancePage);
        paletteGroupBox->setObjectName(QStringLiteral("paletteGroupBox"));
        _2 = new QVBoxLayout(paletteGroupBox);
        _2->setObjectName(QStringLiteral("_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        defaultPaletteButton = new QRadioButton(paletteGroupBox);
        defaultPaletteButton->setObjectName(QStringLiteral("defaultPaletteButton"));
        defaultPaletteButton->setChecked(true);

        horizontalLayout->addWidget(defaultPaletteButton);

        customPaletteButton = new QRadioButton(paletteGroupBox);
        customPaletteButton->setObjectName(QStringLiteral("customPaletteButton"));

        horizontalLayout->addWidget(customPaletteButton);

        horizontalSpacer_3 = new QSpacerItem(230, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        _2->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        colorScheeLabel = new QLabel(paletteGroupBox);
        colorScheeLabel->setObjectName(QStringLiteral("colorScheeLabel"));
        colorScheeLabel->setEnabled(false);

        horizontalLayout_2->addWidget(colorScheeLabel);

        colorSchemeComboBox = new QComboBox(paletteGroupBox);
        colorSchemeComboBox->setObjectName(QStringLiteral("colorSchemeComboBox"));
        colorSchemeComboBox->setEnabled(false);
        colorSchemeComboBox->setMinimumSize(QSize(150, 0));

        horizontalLayout_2->addWidget(colorSchemeComboBox);

        colorSchemeButton = new QToolButton(paletteGroupBox);
        colorSchemeButton->setObjectName(QStringLiteral("colorSchemeButton"));
        colorSchemeButton->setEnabled(false);
        colorSchemeButton->setPopupMode(QToolButton::InstantPopup);
        colorSchemeButton->setArrowType(Qt::NoArrow);

        horizontalLayout_2->addWidget(colorSchemeButton);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        _2->addLayout(horizontalLayout_2);


        gridLayout_4->addWidget(paletteGroupBox, 2, 0, 1, 3);


        retranslateUi(AppearancePage);
        QObject::connect(customPaletteButton, SIGNAL(toggled(bool)), colorScheeLabel, SLOT(setEnabled(bool)));
        QObject::connect(customPaletteButton, SIGNAL(toggled(bool)), colorSchemeComboBox, SLOT(setEnabled(bool)));
        QObject::connect(customPaletteButton, SIGNAL(toggled(bool)), colorSchemeButton, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(AppearancePage);
    } // setupUi

    void retranslateUi(QWidget *AppearancePage)
    {
        label->setText(QApplication::translate("AppearancePage", "Style:", 0));
        groupBox->setTitle(QApplication::translate("AppearancePage", "Preview", 0));
        paletteComboBox->clear();
        paletteComboBox->insertItems(0, QStringList()
         << QApplication::translate("AppearancePage", "Active palette", 0)
         << QApplication::translate("AppearancePage", "Inactive palette", 0)
         << QApplication::translate("AppearancePage", "Disabled palette", 0)
        );
        paletteGroupBox->setTitle(QApplication::translate("AppearancePage", "Palette", 0));
        defaultPaletteButton->setText(QApplication::translate("AppearancePage", "Default", 0));
        customPaletteButton->setText(QApplication::translate("AppearancePage", "Custom", 0));
        colorScheeLabel->setText(QApplication::translate("AppearancePage", "Color scheme:", 0));
        colorSchemeButton->setText(QApplication::translate("AppearancePage", "...", 0));
        Q_UNUSED(AppearancePage);
    } // retranslateUi

};

namespace Ui {
    class AppearancePage: public Ui_AppearancePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_APPEARANCEPAGE_H
