/********************************************************************************
** Form generated from reading UI file 'interfacepage.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INTERFACEPAGE_H
#define UI_INTERFACEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_InterfacePage
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_5;
    QSpinBox *doubleClickIntervalSpinBox;
    QSpinBox *cursorFlashTimeSpinBox;
    QComboBox *comboBoxEffectComboBox;
    QComboBox *toolTipEffectComboBox;
    QComboBox *toolBoxEffectComboBox;
    QLabel *label_6;
    QComboBox *menuEffectComboBox;
    QCheckBox *guiEffectsCheckBox;
    QLabel *label_7;
    QComboBox *buttonLayoutComboBox;
    QCheckBox *menuIconsCheckBox;
    QCheckBox *dialogIconsCheckBox;
    QCheckBox *singleClickCheckBox;
    QLabel *label_8;
    QComboBox *toolButtonStyleComboBox;
    QLabel *label_9;
    QSpinBox *wheelScrollLinesSpinBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *InterfacePage)
    {
        if (InterfacePage->objectName().isEmpty())
            InterfacePage->setObjectName(QStringLiteral("InterfacePage"));
        InterfacePage->resize(498, 449);
        InterfacePage->setWindowTitle(QStringLiteral("Form"));
        gridLayout = new QGridLayout(InterfacePage);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalSpacer = new QSpacerItem(20, 259, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName(QStringLiteral("formLayout"));
        label = new QLabel(InterfacePage);
        label->setObjectName(QStringLiteral("label"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label);

        label_2 = new QLabel(InterfacePage);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label_2);

        label_3 = new QLabel(InterfacePage);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(5, QFormLayout::LabelRole, label_3);

        label_4 = new QLabel(InterfacePage);
        label_4->setObjectName(QStringLiteral("label_4"));

        formLayout->setWidget(6, QFormLayout::LabelRole, label_4);

        label_5 = new QLabel(InterfacePage);
        label_5->setObjectName(QStringLiteral("label_5"));

        formLayout->setWidget(7, QFormLayout::LabelRole, label_5);

        doubleClickIntervalSpinBox = new QSpinBox(InterfacePage);
        doubleClickIntervalSpinBox->setObjectName(QStringLiteral("doubleClickIntervalSpinBox"));
        doubleClickIntervalSpinBox->setMaximum(2000);

        formLayout->setWidget(0, QFormLayout::FieldRole, doubleClickIntervalSpinBox);

        cursorFlashTimeSpinBox = new QSpinBox(InterfacePage);
        cursorFlashTimeSpinBox->setObjectName(QStringLiteral("cursorFlashTimeSpinBox"));
        cursorFlashTimeSpinBox->setMaximum(4000);

        formLayout->setWidget(1, QFormLayout::FieldRole, cursorFlashTimeSpinBox);

        comboBoxEffectComboBox = new QComboBox(InterfacePage);
        comboBoxEffectComboBox->setObjectName(QStringLiteral("comboBoxEffectComboBox"));
        comboBoxEffectComboBox->setEnabled(false);

        formLayout->setWidget(5, QFormLayout::FieldRole, comboBoxEffectComboBox);

        toolTipEffectComboBox = new QComboBox(InterfacePage);
        toolTipEffectComboBox->setObjectName(QStringLiteral("toolTipEffectComboBox"));
        toolTipEffectComboBox->setEnabled(false);

        formLayout->setWidget(6, QFormLayout::FieldRole, toolTipEffectComboBox);

        toolBoxEffectComboBox = new QComboBox(InterfacePage);
        toolBoxEffectComboBox->setObjectName(QStringLiteral("toolBoxEffectComboBox"));
        toolBoxEffectComboBox->setEnabled(false);

        formLayout->setWidget(7, QFormLayout::FieldRole, toolBoxEffectComboBox);

        label_6 = new QLabel(InterfacePage);
        label_6->setObjectName(QStringLiteral("label_6"));

        formLayout->setWidget(4, QFormLayout::LabelRole, label_6);

        menuEffectComboBox = new QComboBox(InterfacePage);
        menuEffectComboBox->setObjectName(QStringLiteral("menuEffectComboBox"));
        menuEffectComboBox->setEnabled(false);

        formLayout->setWidget(4, QFormLayout::FieldRole, menuEffectComboBox);

        guiEffectsCheckBox = new QCheckBox(InterfacePage);
        guiEffectsCheckBox->setObjectName(QStringLiteral("guiEffectsCheckBox"));

        formLayout->setWidget(3, QFormLayout::SpanningRole, guiEffectsCheckBox);

        label_7 = new QLabel(InterfacePage);
        label_7->setObjectName(QStringLiteral("label_7"));

        formLayout->setWidget(8, QFormLayout::LabelRole, label_7);

        buttonLayoutComboBox = new QComboBox(InterfacePage);
        buttonLayoutComboBox->setObjectName(QStringLiteral("buttonLayoutComboBox"));

        formLayout->setWidget(8, QFormLayout::FieldRole, buttonLayoutComboBox);

        menuIconsCheckBox = new QCheckBox(InterfacePage);
        menuIconsCheckBox->setObjectName(QStringLiteral("menuIconsCheckBox"));

        formLayout->setWidget(10, QFormLayout::SpanningRole, menuIconsCheckBox);

        dialogIconsCheckBox = new QCheckBox(InterfacePage);
        dialogIconsCheckBox->setObjectName(QStringLiteral("dialogIconsCheckBox"));
        dialogIconsCheckBox->setTristate(true);

        formLayout->setWidget(9, QFormLayout::SpanningRole, dialogIconsCheckBox);

        singleClickCheckBox = new QCheckBox(InterfacePage);
        singleClickCheckBox->setObjectName(QStringLiteral("singleClickCheckBox"));
        singleClickCheckBox->setTristate(true);

        formLayout->setWidget(2, QFormLayout::SpanningRole, singleClickCheckBox);

        label_8 = new QLabel(InterfacePage);
        label_8->setObjectName(QStringLiteral("label_8"));

        formLayout->setWidget(11, QFormLayout::LabelRole, label_8);

        toolButtonStyleComboBox = new QComboBox(InterfacePage);
        toolButtonStyleComboBox->setObjectName(QStringLiteral("toolButtonStyleComboBox"));

        formLayout->setWidget(11, QFormLayout::FieldRole, toolButtonStyleComboBox);

        label_9 = new QLabel(InterfacePage);
        label_9->setObjectName(QStringLiteral("label_9"));

        formLayout->setWidget(12, QFormLayout::LabelRole, label_9);

        wheelScrollLinesSpinBox = new QSpinBox(InterfacePage);
        wheelScrollLinesSpinBox->setObjectName(QStringLiteral("wheelScrollLinesSpinBox"));
        wheelScrollLinesSpinBox->setMinimum(1);
        wheelScrollLinesSpinBox->setMaximum(20);

        formLayout->setWidget(12, QFormLayout::FieldRole, wheelScrollLinesSpinBox);


        gridLayout->addLayout(formLayout, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(238, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);


        retranslateUi(InterfacePage);
        QObject::connect(guiEffectsCheckBox, SIGNAL(toggled(bool)), menuEffectComboBox, SLOT(setEnabled(bool)));
        QObject::connect(guiEffectsCheckBox, SIGNAL(toggled(bool)), comboBoxEffectComboBox, SLOT(setEnabled(bool)));
        QObject::connect(guiEffectsCheckBox, SIGNAL(toggled(bool)), toolTipEffectComboBox, SLOT(setEnabled(bool)));
        QObject::connect(guiEffectsCheckBox, SIGNAL(toggled(bool)), toolBoxEffectComboBox, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(InterfacePage);
    } // setupUi

    void retranslateUi(QWidget *InterfacePage)
    {
        label->setText(QApplication::translate("InterfacePage", "Double click interval:", 0));
        label_2->setText(QApplication::translate("InterfacePage", "Cursor flash time:", 0));
        label_3->setText(QApplication::translate("InterfacePage", "ComboBox effect:", 0));
        label_4->setText(QApplication::translate("InterfacePage", "ToolTip effect:", 0));
        label_5->setText(QApplication::translate("InterfacePage", "ToolBox effect:", 0));
        doubleClickIntervalSpinBox->setSuffix(QApplication::translate("InterfacePage", " ms", 0));
        cursorFlashTimeSpinBox->setSuffix(QApplication::translate("InterfacePage", " ms", 0));
        comboBoxEffectComboBox->clear();
        comboBoxEffectComboBox->insertItems(0, QStringList()
         << QApplication::translate("InterfacePage", "Disable", 0)
         << QApplication::translate("InterfacePage", "Animate", 0)
        );
        toolTipEffectComboBox->clear();
        toolTipEffectComboBox->insertItems(0, QStringList()
         << QApplication::translate("InterfacePage", "Disable", 0)
         << QApplication::translate("InterfacePage", "Animate", 0)
         << QApplication::translate("InterfacePage", "Fade", 0)
        );
        toolBoxEffectComboBox->clear();
        toolBoxEffectComboBox->insertItems(0, QStringList()
         << QApplication::translate("InterfacePage", "Disable", 0)
         << QApplication::translate("InterfacePage", "Animate", 0)
        );
        label_6->setText(QApplication::translate("InterfacePage", "Menu effect:", 0));
        menuEffectComboBox->clear();
        menuEffectComboBox->insertItems(0, QStringList()
         << QApplication::translate("InterfacePage", "Disable", 0)
         << QApplication::translate("InterfacePage", "Animate", 0)
         << QApplication::translate("InterfacePage", "Fade", 0)
        );
        guiEffectsCheckBox->setText(QApplication::translate("InterfacePage", "Enable gui effects", 0));
        label_7->setText(QApplication::translate("InterfacePage", "Dialog buttons layout:", 0));
        menuIconsCheckBox->setText(QApplication::translate("InterfacePage", "Menus have icons", 0));
        dialogIconsCheckBox->setText(QApplication::translate("InterfacePage", "Dialog buttons have icons", 0));
        singleClickCheckBox->setText(QApplication::translate("InterfacePage", "Activate item on single-click", 0));
        label_8->setText(QApplication::translate("InterfacePage", "Toolbar button style:", 0));
        label_9->setText(QApplication::translate("InterfacePage", "Mouse wheel scroll lines:", 0));
        Q_UNUSED(InterfacePage);
    } // retranslateUi

};

namespace Ui {
    class InterfacePage: public Ui_InterfacePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INTERFACEPAGE_H
