/****************************************************************************
** Meta object code from reading C++ file 'qsspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/qt5ct-0.33/src/qt5ct/qsspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_QSSPage_t {
    QByteArrayData data[11];
    char stringdata0[212];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QSSPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QSSPage_t qt_meta_stringdata_QSSPage = {
    {
QT_MOC_LITERAL(0, 0, 7), // "QSSPage"
QT_MOC_LITERAL(1, 8, 35), // "on_qssListWidget_currentItemC..."
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(4, 62, 7), // "current"
QT_MOC_LITERAL(5, 70, 23), // "on_createButton_clicked"
QT_MOC_LITERAL(6, 94, 21), // "on_editButton_clicked"
QT_MOC_LITERAL(7, 116, 23), // "on_removeButton_clicked"
QT_MOC_LITERAL(8, 140, 23), // "on_renameButton_clicked"
QT_MOC_LITERAL(9, 164, 43), // "on_qssListWidget_customContex..."
QT_MOC_LITERAL(10, 208, 3) // "pos"

    },
    "QSSPage\0on_qssListWidget_currentItemChanged\0"
    "\0QListWidgetItem*\0current\0"
    "on_createButton_clicked\0on_editButton_clicked\0"
    "on_removeButton_clicked\0on_renameButton_clicked\0"
    "on_qssListWidget_customContextMenuRequested\0"
    "pos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QSSPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x08 /* Private */,
       5,    0,   49,    2, 0x08 /* Private */,
       6,    0,   50,    2, 0x08 /* Private */,
       7,    0,   51,    2, 0x08 /* Private */,
       8,    0,   52,    2, 0x08 /* Private */,
       9,    1,   53,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   10,

       0        // eod
};

void QSSPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QSSPage *_t = static_cast<QSSPage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_qssListWidget_currentItemChanged((*reinterpret_cast< QListWidgetItem*(*)>(_a[1])),(*reinterpret_cast< QListWidgetItem*(*)>(_a[2]))); break;
        case 1: _t->on_createButton_clicked(); break;
        case 2: _t->on_editButton_clicked(); break;
        case 3: _t->on_removeButton_clicked(); break;
        case 4: _t->on_renameButton_clicked(); break;
        case 5: _t->on_qssListWidget_customContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject QSSPage::staticMetaObject = {
    { &TabPage::staticMetaObject, qt_meta_stringdata_QSSPage.data,
      qt_meta_data_QSSPage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *QSSPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QSSPage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_QSSPage.stringdata0))
        return static_cast<void*>(const_cast< QSSPage*>(this));
    return TabPage::qt_metacast(_clname);
}

int QSSPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TabPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
