/****************************************************************************
** Meta object code from reading C++ file 'appearancepage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/qt5ct-0.33/src/qt5ct/appearancepage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearancepage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_AppearancePage_t {
    QByteArrayData data[14];
    char stringdata0[217];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AppearancePage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AppearancePage_t qt_meta_stringdata_AppearancePage = {
    {
QT_MOC_LITERAL(0, 0, 14), // "AppearancePage"
QT_MOC_LITERAL(1, 15, 26), // "on_styleComboBox_activated"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 4), // "text"
QT_MOC_LITERAL(4, 48, 32), // "on_colorSchemeComboBox_activated"
QT_MOC_LITERAL(5, 81, 17), // "createColorScheme"
QT_MOC_LITERAL(6, 99, 17), // "changeColorScheme"
QT_MOC_LITERAL(7, 117, 17), // "removeColorScheme"
QT_MOC_LITERAL(8, 135, 15), // "copyColorScheme"
QT_MOC_LITERAL(9, 151, 17), // "renameColorScheme"
QT_MOC_LITERAL(10, 169, 13), // "updatePalette"
QT_MOC_LITERAL(11, 183, 17), // "setPreviewPalette"
QT_MOC_LITERAL(12, 201, 1), // "p"
QT_MOC_LITERAL(13, 203, 13) // "updateActions"

    },
    "AppearancePage\0on_styleComboBox_activated\0"
    "\0text\0on_colorSchemeComboBox_activated\0"
    "createColorScheme\0changeColorScheme\0"
    "removeColorScheme\0copyColorScheme\0"
    "renameColorScheme\0updatePalette\0"
    "setPreviewPalette\0p\0updateActions"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AppearancePage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x08 /* Private */,
       4,    1,   67,    2, 0x08 /* Private */,
       5,    0,   70,    2, 0x08 /* Private */,
       6,    0,   71,    2, 0x08 /* Private */,
       7,    0,   72,    2, 0x08 /* Private */,
       8,    0,   73,    2, 0x08 /* Private */,
       9,    0,   74,    2, 0x08 /* Private */,
      10,    0,   75,    2, 0x08 /* Private */,
      11,    1,   76,    2, 0x08 /* Private */,
      13,    0,   79,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPalette,   12,
    QMetaType::Void,

       0        // eod
};

void AppearancePage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AppearancePage *_t = static_cast<AppearancePage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_styleComboBox_activated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->on_colorSchemeComboBox_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->createColorScheme(); break;
        case 3: _t->changeColorScheme(); break;
        case 4: _t->removeColorScheme(); break;
        case 5: _t->copyColorScheme(); break;
        case 6: _t->renameColorScheme(); break;
        case 7: _t->updatePalette(); break;
        case 8: _t->setPreviewPalette((*reinterpret_cast< const QPalette(*)>(_a[1]))); break;
        case 9: _t->updateActions(); break;
        default: ;
        }
    }
}

const QMetaObject AppearancePage::staticMetaObject = {
    { &TabPage::staticMetaObject, qt_meta_stringdata_AppearancePage.data,
      qt_meta_data_AppearancePage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *AppearancePage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppearancePage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_AppearancePage.stringdata0))
        return static_cast<void*>(const_cast< AppearancePage*>(this));
    return TabPage::qt_metacast(_clname);
}

int AppearancePage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TabPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
